@@ -48,7 +48,7 @@
 #include <linux/socket.h>
 #include <linux/in.h>         /* for sockaddr_in */
 #include <linux/in6.h>         /* for sockaddr_in6 */
-#include <sys/errno.h>
+#include <errno.h>
 #include <sys/uio.h>
 #include <netinet/sctp.h>
 #include <sctputil.h>
